# copy_out.py
#
# Copyright (C) 2013 to 2014 Tim Marston <tim@edm.am>
#
# This file is part of stdhome (hereafter referred to as "this program").
# See http://ed.am/dev/stdhome for more information.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import re
from .copy_base import CopyBaseWalker
import stdhome.the as the
from stdhome.file_matcher import FileMatcher


class CopyOutWalker( CopyBaseWalker ):
	"""The copy-out walker traverses the repo, copying its content to the home
	directory.  During an update, it is run *after* checking for conflicts that
	might occur during copy-out, so any conflicts that exist can be assumed to
	be unimportant and disposable.  In other words, this will happily overwrite
	stuff in the home directory, without regard to its content.

	Walker source:       repo
	Walker destination:  home dir
	Walker traversing:   repo (or a provided file list, which may include stuff
							that no longer exists in the repo
	"""

	def __init__( self, walk_files = None, report = True ):
		CopyBaseWalker.__init__( self )
		self.src_dir = the.repo.full_dir
		self.dst_dir = the.full_home_dir
		self.walk_list = walk_files if walk_files is not None else \
						 self.generate_walk_list( the.repo.full_dir )
		self.check_dst_symlinks = True
		self.check_dst_ignores = True
		self.report = report


	def print_op( self, rel_file, src, op, dst ):

		CopyBaseWalker.print_op( self, rel_file, src, op, dst )

		# verbose reporting
		if the.verbose >= 2:
			if op == '*': op = '<'
			print("  %s%s%s %s" % ( src, op, dst, rel_file ))
